@@ -23,7 +23,7 @@
 
 G_BEGIN_DECLS
 
-#define IDE_BUILD_IDENTIFIER "3.26.2"
+#define IDE_BUILD_IDENTIFIER "3.26.4+"
 
 G_END_DECLS
 
